@@ -170,8 +170,9 @@ class Object # :nodoc:
   # Add a temporary stubbed method replacing +name+ for the duration
   # of the +block+. If +val_or_callable+ responds to #call, then it
   # returns the result of calling it, otherwise returns the value
-  # as-is. Cleans up the stub at the end of the +block+. The method
-  # +name+ must exist before stubbing.
+  # as-is. If stubbed method yields a block, +block_args+ will be
+  # passed along. Cleans up the stub at the end of the +block+. The
+  # method +name+ must exist before stubbing.
   #
   #     def test_stale_eh
   #       obj_under_test = Something.new
@@ -181,8 +182,9 @@ class Object # :nodoc:
   #         assert obj_under_test.stale?
   #       end
   #     end
+  #
 
-  def stub name, val_or_callable, &block
+  def stub name, val_or_callable, *block_args, &block
     new_name = "__minitest_stub__#{name}"
 
     metaclass = class << self; self; end
@@ -195,12 +197,17 @@ class Object # :nodoc:
 
     metaclass.send :alias_method, new_name, name
 
-    metaclass.send :define_method, name do |*args|
-      if val_or_callable.respond_to? :call then
+    metaclass.send :define_method, name do |*args, &blk|
+
+      ret = if val_or_callable.respond_to? :call then
         val_or_callable.call(*args)
       else
         val_or_callable
       end
+
+      blk.call(*block_args) if blk
+
+      ret
     end
 
     yield self
@@ -209,4 +216,5 @@ class Object # :nodoc:
     metaclass.send :alias_method, name, new_name
     metaclass.send :undef_method, new_name
   end
+
 end
