@@ -109,7 +109,7 @@ class TestMinitestMock < Minitest::Test
   end
 
   def test_expectations_can_be_satisfied_via_public_send
-    skip if RUBY_VERSION < "1.9"
+    skip "Doesn't run on 1.8" if RUBY_VERSION < "1.9"
 
     @mock.public_send :foo
     @mock.public_send :meaning_of_life
@@ -309,6 +309,31 @@ class TestMinitestMock < Minitest::Test
 
     assert_equal exp, e.message
   end
+
+  def test_mock_called_via_send
+    mock = Minitest::Mock.new
+    mock.expect(:foo, true)
+
+    mock.send :foo
+    mock.verify
+  end
+
+  def test_mock_called_via___send__
+    mock = Minitest::Mock.new
+    mock.expect(:foo, true)
+
+    mock.__send__ :foo
+    mock.verify
+  end
+
+  def test_mock_called_via_send_with_args
+    mock = Minitest::Mock.new
+    mock.expect(:foo, true, [1,2,3])
+
+    mock.send(:foo, 1, 2, 3)
+    mock.verify
+  end
+
 end
 
 require "minitest/metametameta"
@@ -445,4 +470,20 @@ class TestMinitestStub < Minitest::Test
     @tc.assert_equal true, val
     @tc.assert_equal false, dynamic.found
   end
+
+  def test_mock_with_yield
+    mock = Minitest::Mock.new
+    mock.expect(:write, true) do
+      true
+    end
+    rs = nil
+
+    File.stub(:open, true, mock) do
+      File.open("foo.txt", "r") do |f|
+        rs = f.write
+      end
+    end
+    @tc.assert_equal true, rs
+  end
+
 end
